@@ -4,6 +4,6 @@ from sakkara.model.composable.hierarchical.distribution import DistributionCompo
 from sakkara.model.composable.hierarchical.deterministic import DeterministicComponent
 from sakkara.model.fixed.base import UnrepeatableComponent
 from sakkara.model.fixed.data import DataComponent, data_components
-from sakkara.model.function import FunctionComponent
+from sakkara.model.function.base import FunctionComponent
+from sakkara.model.function.wrapper import f_
 from sakkara.model.utils import build
-from sakkara.model.function_wrapper import f_
