@@ -6,6 +6,7 @@ import pytensor.tensor as pt
 from sakkara.model.base import ModelComponent
 from sakkara.model.composable.base import Composable, T
 from sakkara.relation.groupset import GroupSet
+from sakkara.relation.representation import MinimalTensorRepresentation
 
 
 class HierarchicalComponent(Composable[str, T], ABC):
@@ -29,9 +30,26 @@ class HierarchicalComponent(Composable[str, T], ABC):
     def prebuild(self, groupset: GroupSet) -> None:
         self.build_components(groupset)
 
+    def build_representation(self, groupset: GroupSet):
+        self.representation = MinimalTensorRepresentation(groupset['global'])
+
+        if len(self.group) == 0:
+            for comp in self.subcomponents.values():
+                for g in comp.representation.get_groups():
+                    self.representation.add_group(g)
+        else:
+            for g in self.group:
+                self.representation.add_group(groupset[g])
+            if tuple(map(str, self.representation.groups)) != self.group:
+                raise ValueError('Groups are not a minimal')
+
     def get_built_components(self) -> Dict[str, pt.Variable]:
         built_components = {}
         for key, comp in self.subcomponents.items():
-            built_components[key] = comp.representation.map(comp.variable, self.representation)
+            intermediate_repr = MinimalTensorRepresentation(*self.representation.get_groups(),
+                                                            *comp.representation.get_groups())
+
+            intermediate_var = comp.representation.map(comp.variable, intermediate_repr)
+            built_components[key] = intermediate_repr.map(intermediate_var, self.representation)
 
         return built_components
