@@ -3,7 +3,7 @@ from abc import ABC
 from typing import Any
 
 from sakkara.model.base import ModelComponent
-from sakkara.model.function import FunctionComponent
+from sakkara.model.function.base import FunctionComponent
 
 
 class MathOpBase(ModelComponent, ABC):
@@ -36,4 +36,4 @@ class MathOpBase(ModelComponent, ABC):
         return FunctionComponent.math_op(operator.truediv, other, self)
 
     def __neg__(self):
-        return FunctionComponent(operator.neg, self)
+        return FunctionComponent(operator.neg, None, self)
